@@ -1,4 +1,4 @@
-""" Pylama's shell support. """
+"""Pylama's shell support."""
 
 from __future__ import absolute_import, with_statement
 
@@ -10,10 +10,9 @@ from .core import LOGGER, run
 from .async import check_async
 
 
-def check_path(options, rootdir=None, candidates=None):
-    """ Check path.
+def check_path(options, rootdir=None, candidates=None, code=None):
+    """Check path.
 
-    :param path: Path to file or directory for code checking.
     :param rootdir: Root directory (for making relative file paths)
     :param options: Parsed pylama options (from pylama.config.parse_options)
 
@@ -22,12 +21,13 @@ def check_path(options, rootdir=None, candidates=None):
     """
     if not candidates:
         candidates = []
-        path = op.abspath(options.path)
-        if op.isdir(options.path):
-            for root, _, files in walk(options.path):
-                candidates += [op.relpath(op.join(root, f), CURDIR) for f in files]
-        else:
-            candidates.append(options.path)
+        for path_ in options.paths:
+            path = op.abspath(path_)
+            if op.isdir(path):
+                for root, _, files in walk(path):
+                    candidates += [op.relpath(op.join(root, f), CURDIR) for f in files]
+            else:
+                candidates.append(path)
 
     if rootdir is None:
         rootdir = path if op.isdir(path) else op.dirname(path)
@@ -35,16 +35,12 @@ def check_path(options, rootdir=None, candidates=None):
     paths = []
     for path in candidates:
 
-        if not options.force and not any(l.allow(path) for _, l in options.linters): # noqa
+        if not options.force and not any(l.allow(path) for _, l in options.linters):
             continue
 
         if not op.exists(path):
             continue
 
-        if options.skip and any(p.match(path) for p in options.skip):
-            LOGGER.info('Skip path: %s', path)
-            continue
-
         paths.append(path)
 
     if options.async:
@@ -52,12 +48,12 @@ def check_path(options, rootdir=None, candidates=None):
 
     errors = []
     for path in paths:
-        errors += run(path=path, rootdir=rootdir, options=options)
+        errors += run(path=path, code=code, rootdir=rootdir, options=options)
     return errors
 
 
 def shell(args=None, error=True):
-    """ Endpoint for console.
+    """Endpoint for console.
 
     Parse a command arguments, configuration files and run a checkers.
 
@@ -75,19 +71,26 @@ def shell(args=None, error=True):
     # Install VSC hook
     if options.hook:
         from .hook import install_hook
-        return install_hook(options.path)
+        for path in options.paths:
+            return install_hook(path)
 
     return process_paths(options, error=error)
 
 
 def process_paths(options, candidates=None, error=True):
-    """ Process files and log errors. """
+    """Process files and log errors."""
     errors = check_path(options, rootdir=CURDIR, candidates=candidates)
-    pattern = "%(filename)s:%(lnum)s:%(col)s: %(text)s"
-    if options.format == 'pylint':
+
+    if options.format in ['pycodestyle', 'pep8']:
+        pattern = "%(filename)s:%(lnum)s:%(col)s: %(text)s"
+    elif options.format == 'pylint':
         pattern = "%(filename)s:%(lnum)s: [%(type)s] %(text)s"
+    else:  # 'parsable'
+        pattern = "%(filename)s:%(lnum)s:%(col)s: [%(type)s] %(text)s"
 
     for er in errors:
+        if options.abspath:
+            er._info['filename'] = op.abspath(er.filename)
         LOGGER.warning(pattern, er._info)
 
     if error:
@@ -98,3 +101,5 @@ def process_paths(options, candidates=None, error=True):
 
 if __name__ == '__main__':
     shell()
+
+# pylama:ignore=F0001
